#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchMovable2(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchMovable2
                | 
                | Manage rotation of a schematic object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_movable2 = com_object

    def rotate_at_point(self, i_db1_rotation_angle_in_radian: float, i_db2_center_point: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateAtPoint(double iDb1RotationAngleInRadian,
                | CATSafeArrayVariant iDb2CenterPoint)
                | 
                |     Rotate a schematic object with an angle in radian at a
                |     point.
                | 
                |     Parameters:
                | 
                |         iDb1RotationAngleInRadian
                |             Rotation angle (from x-axis) in radian. 
                |         iDb2CenterPoint
                |             X-Y components of a center point of rotation. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchMovable2
                | 
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.RotateAtPoint,dbVar2

        :param float i_db1_rotation_angle_in_radian:
        :param tuple i_db2_center_point:
        :rtype: tuple
        """
        return self.sch_movable2.RotateAtPoint(i_db1_rotation_angle_in_radian, i_db2_center_point)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'rotate_at_point'
        # # vba_code = """
        # # Public Function rotate_at_point(sch_movable2)
        # #     Dim iDb1RotationAngleInRadian (2)
        # #     sch_movable2.RotateAtPoint iDb1RotationAngleInRadian
        # #     rotate_at_point = iDb1RotationAngleInRadian
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchMovable2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.general_knowledge_interfaces.expert_check_runtime import ExpertCheckRuntime


class ExpertCheck(ExpertCheckRuntime):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    GenKnowledgeInterfaces.ExpertRuleBaseComponentRuntime
                |                        GenKnowledgeInterfaces.ExpertCheckRuntime
                |                             ExpertCheck
                | 
                | Represents the edition part of a check.
                | The following example shows how to access the Check check1 from an existing
                | RuleSet RS1 of the RuleBase RB1
                | 
                |  Dim CATDocs As Document
                |  Set CATDocs   = CATIA.Documents
                |  Dim partdoc As PartDocument
                |  Set partdoc   = CATDocs.Add("CATPart")
                |  Dim part As Part
                |  Set part      = partdoc.Part
                |  Dim relations As Relations
                |  Set relations = part.Relations
                |  Dim Rulebase As ExpertRuleBaseRuntime
                |  Set RuleBase  = relations.Item("RB1")
                |  Dim Ruleset As ExpertRuleSetRuntime
                |  Set RuleSet	 = RuleBase.RuleSet.ExpertRuleBaseComponentRuntimes.Item("RS1")
                |  Dim Check1 As ExpertCheckRuntime
                |  Set Check1	 = RuleSet.ExpertRuleBaseComponentRuntimes.Item("Check1")
                |  
                | 
                | See also:
                |     Relations, ExpertRuleBase
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_check = com_object

    @property
    def body(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Body() As CATBSTR
                | 
                |     Returns or sets the body of a Check.
                | 
                |     Example:
                | 
                |          Check1.Body = "H.Diameter > 20mm AND GetSubString(P.Name, 1, 6) == "myPad."

        :rtype: str
        """

        return self.expert_check.Body

    @body.setter
    def body(self, value: str):
        """
        :param str value:
        """

        self.expert_check.Body = value

    @property
    def language(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Language() As long
                | 
                |     Returns or sets the language of a check.
                | 
                |     1
                |         KWE language 
                |     2
                |         VB Script

        :rtype: int
        """

        return self.expert_check.Language

    @language.setter
    def language(self, value: int):
        """
        :param int value:
        """

        self.expert_check.Language = value

    @property
    def variables(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Variables() As CATBSTR
                | 
                |     Returns or sets the variable scope of an Expert Check.
                | 
                |     Example:
                | 
                |          Check1.Variables = "H:Hole; P: Pad"

        :rtype: str
        """

        return self.expert_check.Variables

    @variables.setter
    def variables(self, value: str):
        """
        :param str value:
        """

        self.expert_check.Variables = value

    def __repr__(self):
        return f'ExpertCheck(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.part_interfaces.fillet import Fillet


class EdgeFillet(Fillet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             PartInterfaces.Fillet
                |                                 EdgeFillet
                | 
                | Represents the edges-based fillet shape.
                | It is the base object for constant radius edge fillets and variable radius edge
                | fillets.
                | 
                | See also:
                |     ConstRadEdgeFillet, VarRadEdgeFillet
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.edge_fillet = com_object

    @property
    def edge_propagation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EdgePropagation() As CatFilletEdgePropagation
                | 
                |     Returns or sets the edge fillet propagation mode. This propagation mode is
                |     used when computing the edges to be filleted.
                | 
                |     Example:
                |         The following example returns in mode the edge fillet propagation mode
                |         of the firstEdgeFillet edge fillet, and then sets it to
                |         CATMinimalFilletEdgePropagation, so that a minimum numbers of edges will be
                |         filleted:
                | 
                |          Set mode = firstEdgeFillet.EdgePropagation
                |          Set firstEdgeFillet.EdgePropagation = CATMinimalFilletEdgePropagation

        :return: enum cat_fillet_edge_propagation
        :rtype: int
        """

        return self.edge_fillet.EdgePropagation

    @edge_propagation.setter
    def edge_propagation(self, value: int):
        """
        :param int value: enum cat_fillet_edge_propagation
        """

        self.edge_fillet.EdgePropagation = value

    @property
    def edges_to_keep(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EdgesToKeep() As References (Read Only)
                | 
                |     Returns the collection of edges to keep by the edge
                |     fillet.
                | 
                |     Example:
                |         The following example returns in edges the edges to keep of the
                |         constant radius edge fillet firstCstEdgeFillet:
                | 
                |          Set edges = firstCstEdgeFillet.EdgesToKeep

        :rtype: References
        """

        return References(self.edge_fillet.EdgesToKeep)

    def add_edge_to_keep(self, i_edge_to_keep: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddEdgeToKeep(Reference iEdgeToKeep)
                | 
                |     Adds a new edge to keep by the filleting operation. The edge to keep is not
                |     modified by the fillet.
                | 
                |     Parameters:
                | 
                |         iEdgeToKeep
                |             The edge to keep by the filleting operation
                |             The following 
                | 
                |         Boundary object is supported: TriDimFeatEdge. 
                | 
                | Example:
                |     The following example adds the new edge edge to be kept from filleting by
                |     the constant radius edge fillet firstCstEdgeFillet:
                | 
                |      firstCstEdgeFillet.AddEdgeToKeep(edge)

        :param Reference i_edge_to_keep:
        :rtype: None
        """
        return self.edge_fillet.AddEdgeToKeep(i_edge_to_keep.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_edge_to_keep'
        # # vba_code = """
        # # Public Function add_edge_to_keep(edge_fillet)
        # #     Dim iEdgeToKeep (2)
        # #     edge_fillet.AddEdgeToKeep iEdgeToKeep
        # #     add_edge_to_keep = iEdgeToKeep
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_edge_to_keep(self, i_edge_to_withdraw: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawEdgeToKeep(Reference iEdgeToWithdraw)
                | 
                |     Withdraws an edge from those kept by a filleting
                |     operation.
                | 
                |     Parameters:
                | 
                |         iEdgeToWithdraw
                |             The edge to withdraw
                |             The following 
                | 
                |         Boundary object is supported: TriDimFeatEdge. 
                | 
                | Example:
                |     The following example withdraws the edge edge from those kept from
                |     filleting by the constant radius edge fillet
                |     firstCstEdgeFillet:
                | 
                |      firstCstEdgeFillet.WithdrawEdgeToKeep(edge)

        :param Reference i_edge_to_withdraw:
        :rtype: None
        """
        return self.edge_fillet.WithdrawEdgeToKeep(i_edge_to_withdraw.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_edge_to_keep'
        # # vba_code = """
        # # Public Function withdraw_edge_to_keep(edge_fillet)
        # #     Dim iEdgeToWithdraw (2)
        # #     edge_fillet.WithdrawEdgeToKeep iEdgeToWithdraw
        # #     withdraw_edge_to_keep = iEdgeToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'EdgeFillet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty
from pycatia.analysis_interfaces.analysis_entity import AnalysisEntity


class ABQGasketProperty(ABQProperty):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQProperty
                |                         ABQGasketProperty

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_gasket_property = com_object

    @property
    def initial_gap(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitialGap() As double
                | 
                |     Sets or returns the Initial gap value

        :rtype: float
        """

        return self.abq_gasket_property.InitialGap

    @initial_gap.setter
    def initial_gap(self, value: float):
        """
        :param float value:
        """

        self.abq_gasket_property.InitialGap = value

    @property
    def initial_thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitialThickness() As double
                | 
                |     Sets or returns the Initial thickness value

        :rtype: float
        """

        return self.abq_gasket_property.InitialThickness

    @initial_thickness.setter
    def initial_thickness(self, value: float):
        """
        :param float value:
        """

        self.abq_gasket_property.InitialThickness = value

    @property
    def initial_thickness_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitialThicknessType() As InitialThickness_Type
                | 
                |     Sets or returns the Initial thickness type

        :return: enum initial_thickness_type
        :rtype: int
        """

        return self.abq_gasket_property.InitialThicknessType

    @initial_thickness_type.setter
    def initial_thickness_type(self, value: int):
        """
        :param int value: enum initial_thickness_type
        """

        self.abq_gasket_property.InitialThicknessType = value

    @property
    def initial_void(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitialVoid() As double
                | 
                |     Sets or returns the Initial void value

        :rtype: float
        """

        return self.abq_gasket_property.InitialVoid

    @initial_void.setter
    def initial_void(self, value: float):
        """
        :param float value:
        """

        self.abq_gasket_property.InitialVoid = value

    @property
    def stabilization_stiffness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StabilizationStiffness() As double
                | 
                |     Sets or returns the Stabilization stiffness value

        :rtype: float
        """

        return self.abq_gasket_property.StabilizationStiffness

    @stabilization_stiffness.setter
    def stabilization_stiffness(self, value: float):
        """
        :param float value:
        """

        self.abq_gasket_property.StabilizationStiffness = value

    @property
    def stabilization_stiffness_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StabilizationStiffnessType() As
                | StabilizationStiffness_Type
                | 
                |     Sets or returns the Stabilization stiffness type

        :return: enum stabilization_stiffness_type
        :rtype: int
        """

        return self.abq_gasket_property.StabilizationStiffnessType

    @stabilization_stiffness_type.setter
    def stabilization_stiffness_type(self, value: int):
        """
        :param int value: enum stabilization_stiffness_type
        """

        self.abq_gasket_property.StabilizationStiffnessType = value

    @property
    def support_property(self) -> AnalysisEntity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SupportProperty() As AnalysisEntity
                | 
                |     Sets or returns the 3D structrel property.

        :rtype: AnalysisEntity
        """

        return AnalysisEntity(self.abq_gasket_property.SupportProperty)

    @support_property.setter
    def support_property(self, value: AnalysisEntity):
        """
        :param AnalysisEntity value:
        """

        self.abq_gasket_property.SupportProperty = value

    def __repr__(self):
        return f'ABQGasketProperty(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.navigator_interfaces.marker_2D import Marker2D
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Marker2Ds(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Marker2Ds
                | 
                | A collection of Marker2Ds objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Marker2D)
        self.marker_2ds = com_object

    def add2_d_arrow(self, i_coordinates: tuple) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DArrow(CATSafeArrayVariant iCoordinates) As
                | Marker2D
                | 
                |     Creates an arrow marker 2D and adds it to the marker 2D collection. The
                |     arrow is defined using the coordinates of its head and tail
                |     points.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates
                | 
                |                 iCoordinates(0) is the X coordinate of the head
                |                 point
                |                 iCoordinates(1) is the Y coordinate of the head
                |                 point
                |                 iCoordinates(2) is the X coordinate of the tail
                |                 point
                |                 iCoordinates(3) is the Y coordinate of the tail point
                |                 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DArrow As Marker2D
                |             Set NewMarker2DArrow = TheMarker2Ds.Add2DArrow(Positions)

        :param tuple i_coordinates:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DArrow(i_coordinates))

    def add2_d_circle(self, i_coordinates: tuple, i_fill_status: int) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DCircle(CATSafeArrayVariant iCoordinates,
                | long iFillStatus) As Marker2D
                | 
                |     Creates a circle marker 2D and adds it to the marker 2D collection. The
                |     circle is defined using the coordinates of its center and a point through which
                |     it passes.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates
                | 
                |                 iCoordinates(0) is the X coordinate of the
                |                 center
                |                 iCoordinates(1) is the Y coordinate of the
                |                 center
                |                 iCoordinates(2) is the X coordinate of the a point on the
                |                 circle
                |                 iCoordinates(3) is the Y coordinate of the a point on the
                |                 circle 
                | 
                |         iFillStatus
                |             The filling status (1 the figure is filled, 0 the figure is not
                |             filled). 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DCircle As Marker2D
                |             Set NewMarker2DCircle = TheMarker2Ds.Add2DCircle(Positions, 0)

        :param tuple i_coordinates:
        :param int i_fill_status:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DCircle(i_coordinates, i_fill_status))

    def add2_d_free_hand(self, i_coordinates: tuple) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DFreeHand(CATSafeArrayVariant iCoordinates) As
                | Marker2D
                | 
                |     Creates a free hand drawing marker 2D and adds it to the marker 2D
                |     collection. The free hand drawing is defined using the coordinates of a series
                |     of points.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates
                | 
                |                 iCoordinates(0) is the X coordinate of the first
                |                 point
                |                 iCoordinates(1) is the Y coordinate of the first
                |                 point
                |                 iCoordinates(2) is the X coordinate of the second
                |                 point
                |                 iCoordinates(3) is the Y coordinate of the second
                |                 point
                |                 iCoordinates(n*2-2) is the X coordinate of the n-th
                |                 point
                |                 iCoordinates(n*2-1) is the Y coordinate of the n-th point
                |                 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DFreeHand As Marker2D
                |             Set NewMarker2DFreeHand = TheMarker2Ds.Add2DFreeHand(Positions)

        :param tuple i_coordinates:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DFreeHand(i_coordinates))

    def add2_d_line(self, i_coordinates: tuple) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DLine(CATSafeArrayVariant iCoordinates) As
                | Marker2D
                | 
                |     Creates a line marker 2D and adds it to the marker 2D collection. The line
                |     segment is defined using the coordinates of its two
                |     endpoints.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates of the endpoints
                | 
                |                 iCoordinates(0) is the X coordinate of the first
                |                 endpoint
                |                 iCoordinates(1) is the Y coordinate of the first
                |                 endpoint
                |                 iCoordinates(2) is the X coordinate of the second
                |                 endpoint
                |                 iCoordinates(3) is the Y coordinate of the second endpoint
                |                 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DLine As Marker2D
                |             Set NewMarker2DLine = TheMarker2Ds.Add2DLine(Positions)

        :param tuple i_coordinates:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DLine(i_coordinates))

    def add2_d_picture(self, i_coordinates: tuple, i_path: str) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DPicture(CATSafeArrayVariant iCoordinates,
                | CATBSTR iPath) As Marker2D
                | 
                |     Creates a picture marker 2D and adds it to the marker 2D collection. The
                |     picture is defined as a rectangle whose bottom-left and top-right corners are
                |     given.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates of the corners
                | 
                |                 iCoordinates(0) is the X coordinate of the bottom-left
                |                 point
                |                 iCoordinates(1) is the Y coordinate of the bottom-left
                |                 point
                |                 iCoordinates(2) is the X coordinate of the top-right
                |                 point
                |                 iCoordinates(3) is the Y coordinate of the top-right point
                |                 
                | 
                |         iPath
                |             The path to the picture file 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DPicture As Marker2D
                |             Set NewMarker2DPicture = TheMarker2Ds.Add2DPicture(Positions, "e:\\picture.bmp")

        :param tuple i_coordinates:
        :param str i_path:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DPicture(i_coordinates, i_path))

    def add2_d_rectangle(self, i_coordinates: tuple, i_fill_status: int) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DRectangle(CATSafeArrayVariant iCoordinates,
                | long iFillStatus) As Marker2D
                | 
                |     Creates a rectangle marker 2D and adds it to the marker 2D collection. The
                |     rectangle is defined using the coordinates of its bottom-left and top-right
                |     corners.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates
                | 
                |                 iCoordinates(0) is the X coordinate of the bottom-left
                |                 point
                |                 iCoordinates(1) is the Y coordinate of the bottom-left
                |                 point
                |                 iCoordinates(2) is the X coordinate of the top-right
                |                 point
                |                 iCoordinates(3) is the Y coordinate of the top-right point
                |                 
                | 
                |         iFillStatus
                |             The filling status (1 the figure is filled, 0 the figure is not
                |             filled). 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DRectangle As Marker2D
                |             Set NewMarker2DRectangle = TheMarker2Ds.Add2DRectangle(Positions, 0)

        :param tuple i_coordinates:
        :param int i_fill_status:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DRectangle(i_coordinates, i_fill_status))

    def add2_d_text(self, i_coordinates: tuple, i_text: str) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add2DText(CATSafeArrayVariant iCoordinates,
                | CATBSTR iText) As Marker2D
                | 
                |     Creates a text marker 2D and adds it to the marker 2D collection. The text
                |     is anchored using the coordinates of its bottom-left
                |     point.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates
                | 
                |                 iCoordinates(0) is the X coordinate of the bottom-left
                |                 point
                |                 iCoordinates(1) is the Y coordinate of the bottom-left point
                |                 
                | 
                |         iText
                |             The text 
                | 
                |     Returns:
                |         The created marker 2D 
                |     Example:
                | 
                |              This example creates a new marker 2D in the TheMarker2Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker2DText As Marker2D
                |             Set NewMarker2DText = TheMarker2Ds.Add2DText(Positions, "example")

        :param tuple i_coordinates:
        :param str i_text:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Add2DText(i_coordinates, i_text))

    def item(self, i_index: cat_variant) -> Marker2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Marker2D
                | 
                |     Returns a marker 2D using its index from the Marker2Ds
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the marker 2D to retrieve from the collection of
                |             Marker2Ds. As a numerics, this index is the rank of the marker 2D in the
                |             collection. The index of the first marker 2D in the collection is 1, and the
                |             index of the last marker 2D is Count. 
                | 
                |     Returns:
                |         The retrieved marker 2D 
                |     Example:
                | 
                |              This example retrieves in ThisMarker2D the ninth marker 2D
                |              
                |             from the TheMarker2Ds collection. 
                |             
                | 
                |             Dim ThisMarker2D As Marker2D
                |             Set ThisMarker2D = TheMarker2Ds.Item(9)

        :param cat_variant i_index:
        :rtype: Marker2D
        """
        return Marker2D(self.marker_2ds.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a marker 2D from the Marker2Ds collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the marker 2D to retrieve from he collection of
                |             Marker2Ds. As a numerics, this index is the rank of the marker 2D in the
                |             collection. The index of the first marker 2D in the collection is 1, and the
                |             index of the last marker 2D is Count. 
                | 
                |     Example:
                | 
                |              The following example removes the tenth marker 2D from the
                |              TheMarker2Ds collection.
                |             
                | 
                |             TheMarker2Ds.Remove(10)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.marker_2ds.Remove(i_index)

    def __getitem__(self, n: int) -> Marker2D:
        if (n + 1) > self.count:
            raise StopIteration

        return Marker2D(self.marker_2ds.Item(n + 1))

    def __iter__(self) -> Iterator[Marker2D]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Marker2Ds(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchRouteAlternateGraphic(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchRouteAlternateGraphic
                | 
                | Manage alternative graphical primitives of a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_route_alternate_graphic = com_object

    def add_alternate_graphic(self, i_initial_xy_position: tuple, o_added_grr: SchGRR) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAlternateGraphic(CATSafeArrayVariant
                | iInitialXYPosition,
                | SchGRR oAddedGRR)
                | 
                |     Add an alternate graphical primitive to a route. The alternate graphical
                |     style is determined by the application. on the Schematic component in order to
                |     specify the graphic style. on the Schematic component in order to identify the
                |     component as an assembly.
                | 
                |     Parameters:
                | 
                |         iInitialXYPosition
                |             The initial position for calculating the display of the graphic. If
                |             NULL, the start point will be calculated based on the route graphic path of the
                |             first assembly member to this Schematic component.
                |             
                |         oAddedGRR
                |             The route alternate graphical primitive that is added to the route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRouteAlternateGraphic
                |          Dim dbVar1(x) As CATSafeArrayVariant
                |          Dim objArg2 As SchGRR
                |           ...
                |          objThisIntf.AddAlternateGraphicdbVar1,objArg2

        :param tuple i_initial_xy_position:
        :param SchGRR o_added_grr:
        :rtype: tuple
        """
        return self.sch_route_alternate_graphic.AddAlternateGraphic(i_initial_xy_position, o_added_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_alternate_graphic'
        # # vba_code = """
        # # Public Function add_alternate_graphic(sch_route_alternate_graphic)
        # #     Dim iInitialXYPosition (2)
        # #     sch_route_alternate_graphic.AddAlternateGraphic iInitialXYPosition
        # #     add_alternate_graphic = iInitialXYPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_alternate_graphics(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListAlternateGraphics() As SchListOfObjects
                | 
                |     Lists the alternate graphics of a route. The list contains all objects of
                |     the same alternate graphic style. The style is determined must be implemented
                |     on the Schematic component in order to specify the graphic
                |     style.
                | 
                |     Parameters:
                | 
                |         oLGRR
                |             A list of the alternate graphic objects. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteAlternateGraphic
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListAlternateGraphics

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_route_alternate_graphic.ListAlternateGraphics())

    def remove_all_alternate_graphics(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllAlternateGraphics()
                | 
                |     Removes all alternate graphical primitives.
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteAlternateGraphic
                |           ...
                |          objThisIntf.RemoveAllAlternateGraphics

        :rtype: None
        """
        return self.sch_route_alternate_graphic.RemoveAllAlternateGraphics()

    def remove_all_alternate_graphics_of_style(self, i_style: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllAlternateGraphicsOfStyle(CatSchIDLRouteAlternateGraphicStyle
                | iStyle)
                | 
                |     Removes all alternate graphical primitives of the given
                |     style.
                | 
                |     Parameters:
                | 
                |         iStyle
                |             An enum of the style of alternate graphic to remove.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRouteAlternateGraphic
                | 
                |           ...
                |          objThisIntf.RemoveAllAlternateGraphicsOfStyleCatSchIDLRouteAlternateGraphicStyle_Enum

        :param int i_style: enum cat_sch_idl_route_alternate_graphic_style
        :rtype: None
        """
        return self.sch_route_alternate_graphic.RemoveAllAlternateGraphicsOfStyle(i_style)

    def remove_alternate_graphic(self, i_grr_to_be_removed: SchGRR) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAlternateGraphic(SchGRR iGRRToBeRemoved)
                | 
                |     Remove an alternate graphical primitive from a route.
                | 
                |     Parameters:
                | 
                |         iGRRToBeRemoved
                |             The route alternate graphic to be removed from the route. The input
                |             graphic will be removed as long as there are at least two alternate graphics of
                |             that style on the route. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteAlternateGraphic
                |          Dim objArg1 As SchGRR
                |           ...
                |          objThisIntf.RemoveAlternateGraphicobjArg1

        :param SchGRR i_grr_to_be_removed:
        :rtype: None
        """
        return self.sch_route_alternate_graphic.RemoveAlternateGraphic(i_grr_to_be_removed.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_alternate_graphic'
        # # vba_code = """
        # # Public Function remove_alternate_graphic(sch_route_alternate_graphic)
        # #     Dim iGRRToBeRemoved (2)
        # #     sch_route_alternate_graphic.RemoveAlternateGraphic iGRRToBeRemoved
        # #     remove_alternate_graphic = iGRRToBeRemoved
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchRouteAlternateGraphic(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.assembly_interfaces.assembly_feature import AssemblyFeature
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.body import Body
from pycatia.product_structure_interfaces.product import Product
from pycatia.sketcher_interfaces.sketch import Sketch
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AssemblyFeatures(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AssemblyFeatures
                | 
                | A collection of all the AssemblyFeature objects of a product.
                | 
                | See also:
                |     AssemblyFeature
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AssemblyFeature)
        self.assembly_features = com_object

    def add_assembly_add(self, i_body: Body, i_body_comp: Product, i_component: Product) -> AssemblyFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAssemblyAdd(Body iBody,
                | Product iBodyComp,
                | Product iComponent) As AssemblyFeature
                | 
                |     Creates a new AssemblyBoolean object by adding a body to the
                |     assembly.
                | 
                |     Parameters:
                | 
                |         iBody
                |             The body to add 
                |         iBodyComp
                |             The component that contains the body to add 
                |         iComponent
                |             The component with respect to which the AssemblyBoolean object to
                |             create will be positioned 
                | 
                |     Returns:
                |         The created AssemblyBoolean object 
                |     Example:
                |         This example creates the addBody AssemblyBoolean object in the
                |         assemblyFeats collection using a body referenced as bodyToAdd contained in the
                |         bodyToAddComp component, and positioned with respect to the positioningComp
                |         component.
                | 
                |          Dim addBody As AssemblyBoolean
                |          Set addBody = assemblyFeats.AddAssemblyAdd(bodyToAdd,     _
                |                                                     bodyToAddComp, _
                |                                                     itioningComp)

        :param Body i_body:
        :param Product i_body_comp:
        :param Product i_component:
        :rtype: AssemblyFeature
        """
        return AssemblyFeature(
            self.assembly_features.AddAssemblyAdd(
                i_body.com_object,
                i_body_comp.com_object,
                i_component.com_object
            )
        )

    def add_assembly_hole(
            self,
            i_sketch: Sketch,
            i_sketch_comp:
            Product,
            i_depth: float,
            i_component: Product) -> AssemblyFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAssemblyHole(Sketch iSketch,
                | Product iSketchComp,
                | double iDepth,
                | Product iComponent) As AssemblyFeature
                | 
                |     Creates a new AssemblyHole object.
                | 
                |     Parameters:
                | 
                |         iSketch
                |             The sketch defining the hole reference plane and anchor
                |             point.
                |             This sketch must contain a single point that defines the hole axis:
                |             the hole axis in 3D passes through that point and is normal to the sketch
                |             plane. 
                |         iSketchComp
                |             The component that contains the sketch 
                |         iDepth
                |             The hole depth 
                |         iComponent
                |             The component with respect to which the AssemblyHole object to
                |             create will be positioned 
                | 
                |     Returns:
                |         The created AssemblyHole object 
                |     Example:
                |         This example creates the hole AssemblyHole object in the assemblyFeats
                |         collection using a sketch referenced as holeSketch contained in the
                |         holeSketchComp component, with a depth of 60mm, and positioned with respect to
                |         the positioningComp component.
                | 
                |          Dim hole As AssemblyHole
                |          Set hole = assemblyFeats.AddAssemblyHole(holeSketch,     _
                |                                                   holeSketchComp,
                |                                                   _
                |                                                   60,            
                |                                                   _
                |                                                   positioningComp)

        :param Sketch i_sketch:
        :param Product i_sketch_comp:
        :param float i_depth:
        :param Product i_component:
        :rtype: AssemblyFeature
        """
        return AssemblyFeature(
            self.assembly_features.AddAssemblyHole(
                i_sketch.com_object,
                i_sketch_comp.com_object,
                i_depth,
                i_component.com_object
            )
        )

    def add_assembly_pocket(
            self,
            i_sketch: Sketch,
            i_sketch_comp: Product,
            i_depth: float,
            i_component: Product) -> AssemblyFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAssemblyPocket(Sketch iSketch,
                | Product iSketchComp,
                | double iDepth,
                | Product iComponent) As AssemblyFeature
                | 
                |     Creates a new AssemblyPocket object.
                | 
                |     Parameters:
                | 
                |         iSketch
                |             The sketch defining the pocket base 
                |         iSketchComp
                |             The component that contains the sketch 
                |         iDepth
                |             The pocket depth 
                |         iComponent
                |             The component with respect to which the AssemblyPocket object to
                |             create will be positioned 
                | 
                |     Returns:
                |         The created AssemblyPocket object 
                |     Example:
                |         This example creates the pocket AssemblyPocket object in the
                |         assemblyFeats collection using a sketch referenced as pocketSketch contained in
                |         the pocketSketchComp component, with a depth of 20mm, and positioned with
                |         respect to the positioningComp component.
                | 
                |          Dim pocket As AssemblyPocket
                |          Set pocket = assemblyFeats.AddAssemblyPocket(pocketSketch,     _
                |                                                       pocketSketchComp,
                |                                                       _
                |                                                       20,              
                |                                                       _
                |                                                       positioningComp)

        :param Sketch i_sketch:
        :param Product i_sketch_comp:
        :param float i_depth:
        :param Product i_component:
        :rtype: AssemblyFeature
        """
        return AssemblyFeature(
            self.assembly_features.AddAssemblyPocket(
                i_sketch.com_object,
                i_sketch_comp.com_object,
                i_depth,
                i_component.com_object
            )
        )

    def add_assembly_remove(self, i_body: Body, i_body_comp: Product, i_component: Product) -> AssemblyFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAssemblyRemove(Body iBody,
                | Product iBodyComp,
                | Product iComponent) As AssemblyFeature
                | 
                |     Creates a new AssemblyBoolean object by removing a body from the
                |     assembly.
                | 
                |     Parameters:
                | 
                |         iBody
                |             The body to remove 
                |         iBodyComp
                |             The component that contains the body to remove 
                |         iComponent
                |             The component with respect to which the AssemblyBoolean object to
                |             create will be positioned 
                | 
                |     Returns:
                |         The created AssemblyBoolean object 
                |     Example:
                |         This example creates the removeBody AssemblyBoolean object in the
                |         assemblyFeats collection using a body referenced as bodyToRemove contained in
                |         the bodyToRemoveComp component, and positioned with respect to the
                |         positioningComp component.
                | 
                |          Dim removeBody As AssemblyBoolean
                |          Set removeBody = assemblyFeats.AddAssemblyRemove(bodyToRemove,
                |                                                           _
                |                                                           bodyToRemoveComp,
                |                                                           _
                |                                                           positioningComp)

        :param Body i_body:
        :param Product i_body_comp:
        :param Product i_component:
        :rtype: AssemblyFeature
        """
        return AssemblyFeature(
            self.assembly_features.AddAssemblyRemove(
                i_body.com_object,
                i_body_comp.com_object,
                i_component.com_object
            )
        )

    def add_assembly_split(
            self,
            i_splitting_element: Reference,
            i_splitting_elem_comp: Product,
            i_split_side: int,
            i_component: Product) -> AssemblyFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAssemblySplit(Reference iSplittingElement,
                | Product iSplittingElemComp,
                | CatSplitSide iSplitSide,
                | Product iComponent) As AssemblyFeature
                | 
                |     Creates a new AssemblySplit object.
                | 
                |     Parameters:
                | 
                |         iSplittingElement
                |             The face or plane that will split the current body
                |             
                |         iSplittingElemComp
                |             The component that contains the splitting element 
                |         iSplitSide
                |             The specification for which side of the current body should be kept
                |             at the end of the split operation 
                |         iComponent
                |             The component with respect to which the AssemblySplit object to
                |             create will be positioned 
                | 
                |     Returns:
                |         The created AssemblySplit object 
                |     Example:
                |         This example creates the splitByPlane AssemblySplit object in the
                |         assemblyFeats collection using a plane referenced as splittingPlane contained
                |         in the splittingComp component, in such a way that the material to remove be
                |         the one located in the direction of the splittingPlane normal vector, and
                |         positioned with respect to the positioningComp
                |         component.
                | 
                |          Dim splitByPlane As AssemblySplit
                |          Set splitByPlane = assemblyFeats.AddAssemblySplit(splittingPlane,  _
                |                                                            splittingComp,  
                |                                                            _
                |                                                            catPositiveSide,
                |                                                            _
                |                                                           positioningComp)

        :param Reference i_splitting_element:
        :param Product i_splitting_elem_comp:
        :param int i_split_side: enum cat_split_side
        :param Product i_component:
        :rtype: AssemblyFeature
        """
        return AssemblyFeature(
            self.assembly_features.AddAssemblySplit(
                i_splitting_element.com_object,
                i_splitting_elem_comp.com_object,
                i_split_side,
                i_component.com_object
            )
        )

    def item(self, i_index: cat_variant) -> AssemblyFeature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AssemblyFeature
                | 
                |     Returns an AssemblyFeature object using its index or its name from the
                |     AssemblyFeatures collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the AssemblyFeature object to retrieve
                |             from the AssemblyFeatures collection. As a numerics, this index is the rank of
                |             the AssemblyFeature object in the collection. The index of the first
                |             AssemblyFeature object in the collection is 1, and the index of the last
                |             AssemblyFeature object is Count. As a string, it is the name you assigned to
                |             the AssemblyFeature object using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved AssemblyFeature object 
                |     Example:
                |         This example retrieves the last item in the assemblyFeats
                |         collection.
                | 
                |          Dim lastAssemblyFeat As AssemblyFeature
                |          Set lastAssemblyFeat = assemblyFeats.Item(assemblyFeats.Count)

        :param cat_variant i_index:
        :rtype: AssemblyFeature
        """
        return AssemblyFeature(self.assembly_features.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an AssemblyFeature object from the AssemblyFeatures
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the AssemblyFeature object to remove from
                |             the AssemblyFeatures collection. As a numerics, this index is the rank of the
                |             AssemblyFeature object in the collection. The index of the first
                |             AssemblyFeature object in the collection is 1, and the index of the last
                |             AssemblyFeature object is Count. As a string, it is the name you assigned to
                |             the AssemblyFeature object using the 
                | 
                |         AnyObject.Name property. 
                |     Example:
                |         This example removes the last AssemblyFeature object in the
                |         assemblyFeats collection.
                | 
                |          assemblyFeats.Remove(assemblyFeats.Count)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.assembly_features.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(assembly_features)
        # #     Dim iIndex (2)
        # #     assembly_features.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblyFeatures(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_set import AnalysisSet
from pycatia.analysis_interfaces.analysis_sets import AnalysisSets
from pycatia.system_interfaces.any_object import AnyObject


class AnalysisCase(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisCase
                | 
                | Represent the analysis case object.
                | Role: Interface designed to manage Analysis Case behavior.
                | In the Analysis document, an Analysis Case is the object dedicated to define
                | and manage the environment data necessary to run a computation. This
                | environment is made of sets.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_case = com_object

    @property
    def analysis_sets(self) -> AnalysisSets:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisSets() As AnalysisSets (Read Only)
                | 
                |     Returns the analysis sets collection associated to the analysis
                |     case.
                | 
                |     Returns:
                |         The collection of analysis sets. 
                |     Example:
                |         The following example retrieves the analysis sets collection
                |         ListSets
                | 
                |          Dim MyCase As AnalysisCase
                |          Dim ListSets As AnalysisSets
                |          Set ListSets = MyCase.AnalysisSets

        :rtype: AnalysisSets
        """

        return AnalysisSets(self.analysis_case.AnalysisSets)

    def add_solution(self, i_solution_type: str) -> AnalysisSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddSolution(CATBSTR iSolutionType) As AnalysisSet
                | 
                |     Creates a Solution set defined by its type in the Case.
                | 
                |     Parameters:
                | 
                |         iSolutionType
                |             The feature type of the solution set.
                |             This is a user defined type corresponding to the kind of
                |             computation. For example "StaticSet" 
                | 
                |     Returns:
                |         oSolution The analysis set created. 
                |     Example:
                |         The following example create a solution set ListSets
                | 
                |          Dim MyCase As AnalysisCase
                |          Dim Newsol As AnalysisSet
                |          Set Newsol = MyCase.AddSolution("StaticSet")

        :param str i_solution_type:
        :rtype: AnalysisSet
        """
        return AnalysisSet(self.analysis_case.AddSolution(i_solution_type))

    def compute(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Compute()
                | 
                |     Launch the computation (Update) of an analysis case. This step corresponds
                |     to the "Case Solution" option of the interactive command. 
                | Example:
                |     The following example launches the update of MyCase
                | 
                |      Dim MyCase As AnalysisCase
                |      MyCase.Compute

        :rtype: None
        """
        return self.analysis_case.Compute()

    def compute_mesh_only(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ComputeMeshOnly()
                | 
                |     Launch the computation (Update) of an analysis case. This method
                |     corresponds to the "Mesh Only" option of the interactive command.
                |     
                | Example:
                |     The following example launches the update of MyCase
                | 
                |      Dim MyCase As AnalysisCase
                |      MyCase.ComputeMeshOnly

        :rtype: None
        """
        return self.analysis_case.ComputeMeshOnly()

    def __repr__(self):
        return f'AnalysisCase(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class OrderGenerator(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     OrderGenerator
                | 
                | Interface representing Create Shop Order APIs which generates Shop Order
                | Instance(SOI), against user-given option(s).
                | 
                | 
                | Following gvies the major-steps encountered in a single SOI generation 1) Logs
                | in and secures connection with DPE. 2) Loads the specified job Node. 3) Reslves
                | the Work Instrucitons. 4) Captures Images for activities 5) Generates JobXML
                | and Precedence XML 6) Generates PackNGo data ( Lite or Full) 7) Zips the SOI
                | contents. 8) FTPs the zipped file to FTP server 9) Updates the Release table.
                | 10) Disconnects from DPE.
                | 
                | 
                | Role: Component that implement DNBIAOrderCreation is
                | "OrderGenerator"
                | 
                | 
                | Do not extend this interface
                | 
                | 
                | Example : Refer to CreateShopOrder.CATScript or CreateSOI CATScript at intel_a/VBScript/DPM_SOR
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.order_generator = com_object

    def create_shop_order(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateShopOrder() As short
                | 
                |     Create Shop Order method
                | 
                |     Returns:
                |         SOI response, which in-turn can be obtained using
                |         OrderGenerator.GetErrorDescription

        :rtype: int
        """
        return self.order_generator.CreateShopOrder()

    def create_shop_order2(self, i_xml_input: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateShopOrder2(CATBSTR iXMLInput)
                | 
                |     Create Shop Order using XML as SOI input.
                | 
                |     Parameters:
                | 
                |         iXMLInput
                |             XML input file path Sample schema: Refer
                |             intel_a/resources/xsd/DPM_SOR/CreateSOI.xsd Sample XML input: Refer
                |             intel_a/resources/xml/DPM_SOR/CreateSOI.xml

        :param str i_xml_input:
        :rtype: None
        """
        return self.order_generator.CreateShopOrder2(i_xml_input)

    def get_error_description(self, error_code: int) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetErrorDescription(short ErrorCode) As CATBSTR
                | 
                |     Get Error Description. It deciphers return ERROR code of Create Shop Order
                |     API.
                | 
                |     Parameters:
                | 
                |         iErrorCode
                |             Create Shop Order API return code 
                | 
                |     Returns:
                |         oErrDescription Create Shop Order API return code description

        :param int error_code:
        :rtype: str
        """
        return self.order_generator.GetErrorDescription(error_code)

    def set_dpe_login_info(self, i_dpe_login_id: str, i_dpe_password: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_DPELoginInfo(CATBSTR iDPELoginId,
                | CATBSTR iDPEPassword)
                | 
                |     Set DPE Login Information.
                | 
                |     Parameters:
                | 
                |         iDPELoginId
                |             E5 Login ID for authentication 
                |         iDPEPassword
                |             E5 Password for authentication

        :param str i_dpe_login_id:
        :param str i_dpe_password:
        :rtype: None
        """
        return self.order_generator.set_DPELoginInfo(i_dpe_login_id, i_dpe_password)

    def set_export_3dxml(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_Export3DXML(boolean iRequired)
                | 
                |     Set Export 3D XML Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_Export3DXML(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export3_dxml'
        # # vba_code = """
        # # Public Function set_export3_dxml(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_Export3DXML iRequired
        # #     set_export3_dxml = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_image_capture(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportImageCapture(boolean iRequired)
                | 
                |     Set Export Image Capture Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_ExportImageCapture(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_image_capture'
        # # vba_code = """
        # # Public Function set_export_image_capture(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_ExportImageCapture iRequired
        # #     set_export_image_capture = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_job_xml(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportJobXML(boolean iRequired)
                | 
                |     Set Export Job XML Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_ExportJobXML(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_job_xml'
        # # vba_code = """
        # # Public Function set_export_job_xml(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_ExportJobXML iRequired
        # #     set_export_job_xml = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_prec_xml(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportPrecXML(boolean iRequired)
                | 
                |     Set Export Precedence XML Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_ExportPrecXML(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_prec_xml'
        # # vba_code = """
        # # Public Function set_export_prec_xml(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_ExportPrecXML iRequired
        # #     set_export_prec_xml = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ftp(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_FTP(boolean iRequired)
                | 
                |     Set FTP Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_FTP(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ftp'
        # # vba_code = """
        # # Public Function set_ftp(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_FTP iRequired
        # #     set_ftp = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ftp_server_information(
            self,
            iftp_host_name: str,
            iftp_login_name: str,
            iftp_password: str,
            iftp_outputlocation: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_FTPServerInformation(CATBSTR iftpHostName,
                | CATBSTR iftpLoginName,
                | CATBSTR iftpPassword,
                | CATBSTR iftpOutputlocation)
                | 
                |     Set FTP Information.
                | 
                |     Parameters:
                | 
                |         iftpHostName
                |             Service Host Name for transferering the data 
                |         iftpLoginName
                |             Login Name for authentication to the Service Host Machine for
                |             transfering the data 
                |         iftpPassword
                |             Password for the above login 
                |         iftpOutputlocation
                |             Output Dir where to tranfer the data in the
                |             Machine

        :param str iftp_host_name:
        :param str iftp_login_name:
        :param str iftp_password:
        :param str iftp_outputlocation:
        :rtype: None
        """
        return self.order_generator.set_FTPServerInformation(
            iftp_host_name,
            iftp_login_name,
            iftp_password,
            iftp_outputlocation
        )

    def set_filter_input_string(self, ifilter_input_string: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_FilterInputString(CATBSTR ifilterInputString)
                | 
                |     Specifies the filters to be applied while loading the project. The filters
                |     can be specified either in the new way (V5R18 onwards) or the old
                |     way.
                | 
                |      New Way of Filtering:
                |      
                |      In the new way of filtering different filters can be set for
                |      P,P,R
                |      by specifiying different filter sets for each area and also a global
                |      filter set.
                | 
                | 
                |      Old way of Filtering:
                | 
                |      In case of P,P,R filters, either
                |       (a) A Filter string can be supplied OR
                |       (b) A Calculation Model ID can be supplied
                |      Note: Calculation Model filters MUST only be supplied through their IDs.
                |      
                | 
                |      In case of extended filters, either
                |       (a) A Filter string can be supplied OR
                |       (b) A Calculation Model ID can be supplied OR
                |       (c) Both string AND Model ID can be supplied (Combined effectivity
                |       case)
                |      Note: Calculation Model filters MUST only be supplied through their IDs.
                |      
                | 
                |      In case of effectivity filter mode, one of the following rules can be
                |      supplied
                |       (a) Give the objects whose begin & end dates contains the begin & end
                |       date filters values.
                |           The rule value is 1.
                |       (b) Give the object whose begin & end dates are with in the begin & end
                |       dates filter values.
                |           The rule value is 2.
                |       (c) Give the object whose begin date value is lesser than the begin date
                |       filter value &
                |           the end date value on the object is contained with in the begin & end
                |           date filter values.
                |           The rule value is 4.
                |       (d) Give the object whose begin date value is contained with in the begin
                |       & end date filter values &
                |           the end date value on the object is greater than the end date filter
                |           value.
                |           The rule value is 8.
                |       (e) Give the object whose begin & end dates exactly match with that of
                |       the begin & end date filter values
                |           The rule value is 16.
                |      Note: Combination of the above said rules can also be
                |      used.
                |           For example: If the user wants the combination of rule a & c, then
                |           the value of 5 should be passed
                |      Note: If the user has not specified any value for this filter, then a
                |      default value of 31 (combination of all rules) will be
                |      used.
                |      
                | 
                |     Parameters:
                | 
                |         iFilters
                |             [in]
                | 
                |               The filters to be set. 
                |               This is a list of values separated by XML type tags. User Should
                |               specify tags only from one of the below 
                |               set of tags applicable for new and old
                |               filtering.
                | 
                |               The following tags are supported for New way of
                |               Filtering:
                | 
                |                  <GlobalFilterSetName>Global Filter
                |                  Name</GlobalFilterSetName>
                |                  <ProductFilterSetName>Product Filter
                |                  Name</ProductFilterSetName>
                |                  <ProcessFilterSetName>Process Filter
                |                  Name</ProcessFilterSetName>
                |                  <ResourceFilterSetName>Process Filter
                |                  Name</ResourceFilterSetName>   
                |                  <ModStatementFilterID>Filter
                |                  Value</ModStatementFilterID>
                |                  <ProductFilterByCO>Filter
                |                  Value</ProductFilterByCO>
                |                  <PreFilter>Filter Value</PreFilter>
                |                  <PostFilter>Filter Value</PostFilter>
                |                  <PrePostFilter>Filter Value</PrePostFilter>
                |                  <PlanningStateOwnerFilterID>ID of Planning
                |                  State</PlanningStateOwnerFilterID>
                |                  <PlanningStateOtherFilterID>ID of Planning
                |                  State</PlanningStateOtherFilterID>
                |                  <ApplyImplicitFilter>TRUE or
                |                  FALSE</ApplyImplicitFilter>
                | 
                | 
                |               The following tags are supported for Old way of
                |               Filtering:
                | 
                |                  <ProcessFilter>Filter Value</ProcessFilter>
                |                  <ProcessFilterCalcModelID>ID of Calculation Model
                |                  Filter</ProcessFilterCalcModelID>  
                |                  <ProductFilter>Filter Value</ProductFilter>
                |                  <ProductFilterCalcModelID>ID of Calculation Model
                |                  Filter</ProductFilterCalcModelID>
                |                  <ResourceFilter>Filter Value</ResourceFilter>
                |                  <ResourceFilterCalcModelID>ID of Calculation Model
                |                  Filter</ResourceFilterCalcModelID>
                |                  <StartDateEffectivityFilter>Filter
                |                  Value</StartDateEffectivityFilter>
                |                  <EndDateEffectivityFilter>Filter
                |                  Value</EndDateEffectivityFilter>
                |                  <EffectivityFilterMode>Filter
                |                  Value</EffectivityFilterMode>
                |                  <LineNumberFilter>Filter
                |                  Value</LineNumberFilter>
                |                  <LabelFilter>Filter Value</LabelFilter>
                |                  <ModStatementFilterID>Filter
                |                  Value</ModStatementFilterID>
                |                  <PlanningStateOwnerFilterID>ID of Planning
                |                  State</PlanningStateOwnerFilterID>
                |                  <PlanningStateOtherFilterID>ID of Planning
                |                  State</PlanningStateOtherFilterID>
                |                  <ApplyImplicitFilter>TRUE or
                |                  FALSE</ApplyImplicitFilter>
                |                  <ProcessExtendedEffectivityFilter>Filter
                |                  Value</ProcessExtendedEffectivityFilter>
                |                  <ProcessExtendedEffectivityFilterCalcModelID>ID of Calculation
                |                  ModelFilter</ProcessExtendedEffectivityFilterCalcModelID>
                |                  <ProductExtendedEffectivityFilter>Filter
                |                  Value</ProductExtendedEffectivityFilter>
                |                  <ProductExtendedEffectivityFilterCalcModelID>ID of Calculation
                |                  ModelFilter</ProductExtendedEffectivityFilterCalcModelID>
                |                  <ResourceExtendedEffectivityFilter>Filter
                |                  Value</ResourceExtendedEffectivityFilter> 
                |                  <ResourceExtendedEffectivityFilterCalcModelID>ID of
                |                  Calculation ModelFilter</ResourceExtendedEffectivityFilterCalcModelID>
                |
                |               Attribute filters can be supplied using the following
                |               tags
                |               <AttributeFilters>
                |                  <ProcessAttributeFilters>
                |                    <AttributeFilter>
                |                       <PlanTypeName>Name of the
                |                       Plantype</PlanTypeName>
                |                       <AttributeName>Name of the
                |                       Attribute</AttributeName>
                |                       <Operator>Type of Operator. See list of legal values
                |                       below</Operator>
                |                       <AttributeValue>Value of the
                |                       Attribute</AttributeValue>
                |                       Add more <AttributeValue>...</AttributeValue> if more
                |                       attribute values need to be specified
                |                    </AttributeFilter>
                |                    Add more <AttributeFilter>...</AttributeFilter> if more
                |                    attribute filters need to be specified
                |                  </ProcessAttributeFilters>   
                |                  <ProductAttributeFilters>
                |                    Add <AttributeFilter>...</AttributeFilter> as specified
                |                    above
                |                  </ProductAttributeFilters>
                |                  <ResourceAttributeFilters>
                |                    Add <AttributeFilter>...</AttributeFilter> as specified
                |                    above
                |                  </ResourceAttributeFilters>
                |               </AttributeFilters>
                |               
                | 
                |             Note: Instead of specifying plantype name, the object typename
                |             (e.g., "ergocompprocessdefault, "ergocomporgprocess", etc) can also be supplied
                |             if filter is to be applicable to all plantypes
                |             Note: For the <Operator> tag, the following are the legal
                |             values
                |                =
                |                !=
                |                <
                |                >
                |                <=
                |                >=
                |                LIKE
                |                NOT LIKE
                | 
                |     Example:
                | 
                |             In new way of filtering:
                |            iFilters = "<ProcessFilterSetName>Name</ProcessFilterSetName><ProductFilterSetName>Name</ProductFilterSetName><ResourceFilterSetName>Name</ResourceFilterSetName>"
                |            
                |         The order is NOT important. e.g.,
                |         "<ResourceFilterSetName>...</ResourceFilterSetName>" can come before
                |         "<ProcessFilterSetName>...</ProcessFilterSetName>"
                |          
                |     Example:
                | 
                |             In old way of filtering:
                |            iFilters = "<ProcessFilter>Process Type A</ProcessFilter><LabelFilter>Label B</LabelFilter><LineNumberFilter>10</LineNumberFilter>"
                |            
                |         The order is NOT important. e.g., "<LabelFilter>...</LabelFilter>" can
                |         come before "<ProcessFilter>...</ProcessFilter>"
                |
                |     Example:
                | 
                |             In old way of filtering:
                |            Example with attribute filers. Assuming user wishes to filter on
                |            Line Number 10 and load only those Workplans that are labelled "Workplan A" and
                |            "Workplan C"
                |            
                |         iFilters = "<LineNumberFilter>10</LineNumberFilter><AttributeFilters><ProcessAttributeFilters><AttributeFilter>
                |            <PlanTypeName>Workplan</PlanTypeName>
                |            <AttributeName>name</AttributeName>
                |            <Operator>=</Operator>
                |            <AttributeValue>Workplan A</AttributeValue>
                |            <AttributeValue>Workplan C</AttributeValue>
                |           </AttributeFilter></ProcessAttributeFilters></AttributeFilters>"
                |
                |     Returns:
                |         S_OK if all OK E_INVALIDARG if incorrect input format Refer
                |         DNBMHIInterfaces/PublicInterfaces/DNBIAMHILoadParameters.idl :: SetFilters
                |         method for additional information

        :param str ifilter_input_string:
        :rtype: None
        """
        return self.order_generator.set_FilterInputString(ifilter_input_string)

    def set_generate_pack_n_go(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_GeneratePackNGo(boolean iRequired)
                | 
                |     Set Generate PackNGo Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_GeneratePackNGo(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_generate_pack_n_go'
        # # vba_code = """
        # # Public Function set_generate_pack_n_go(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_GeneratePackNGo iRequired
        # #     set_generate_pack_n_go = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_generate_smg_mapping_xml(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_GenerateSMGMappingXML(boolean iRequired)
                | 
                |     Set Generate SMG Mapping XML Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_GenerateSMGMappingXML(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_generate_smg_mapping_xml'
        # # vba_code = """
        # # Public Function set_generate_smg_mapping_xml(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_GenerateSMGMappingXML iRequired
        # #     set_generate_smg_mapping_xml = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_generate_smg_xml(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_GenerateSMGXML(boolean iRequired)
                | 
                |     Set Generate SMG XML Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_GenerateSMGXML(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_generate_smgxml'
        # # vba_code = """
        # # Public Function set_generate_smgxml(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_GenerateSMGXML iRequired
        # #     set_generate_smgxml = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_generate_smg_xml_exe_path(self, i_required: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_GenerateSMGXmlExePath(CATBSTR iRequired)
                | 
                |     Set Generate SMG XML EXE Path.
                | 
                |     Parameters:
                | 
                |         iRequired
                |             Path to the SMG Generator EXE

        :param str i_required:
        :rtype: None
        """
        return self.order_generator.set_GenerateSMGXmlExePath(i_required)

    def set_lite_pack_n_go(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_LitePackNGo(boolean iRequired)
                | 
                |     Set Lite PackNGo Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_LitePackNGo(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_lite_pack_n_go'
        # # vba_code = """
        # # Public Function set_lite_pack_n_go(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_LitePackNGo iRequired
        # #     set_lite_pack_n_go = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_load_context(self, i_required: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_LoadContext(CATBSTR iRequired)
                | 
                |     Set Load Context Type.
                | 
                |     Parameters:
                | 
                |         iRequestType
                |             Type Of Request
                | 
                |                 Manufacturing
                |                 Volumetric
                |                 User

        :param str i_required:
        :rtype: None
        """
        return self.order_generator.set_LoadContext(i_required)

    def set_load_positions(self, i_required: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_LoadPositions(CATBSTR iRequired)
                | 
                |     Set Load Positions Type.
                | 
                |     Parameters:
                | 
                |         iRequestType
                |             Type Of Request
                | 
                |                 3DStates
                |                 PublishedSimulation

        :param str i_required:
        :rtype: None
        """
        return self.order_generator.set_LoadPositions(i_required)

    def set_manufacturing_context(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ManufacturingContext(boolean iRequired)
                | 
                |     Set Manufacturing Context Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_ManufacturingContext(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_manufacturing_context'
        # # vba_code = """
        # # Public Function set_manufacturing_context(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_ManufacturingContext iRequired
        # #     set_manufacturing_context = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_process_name(self, iprocess_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ProcessName(CATBSTR iprocessName)
                | 
                |     Set Process Name.
                | 
                |     Parameters:
                | 
                |         iprocessName
                |             Process Name to be set for PackNGo CATProcess

        :param str iprocess_name:
        :rtype: None
        """
        return self.order_generator.set_ProcessName(iprocess_name)

    def set_request_type(self, i_requset_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_RequestType(CATBSTR iRequsetType)
                | 
                |     Set Request Type.
                | 
                |     Parameters:
                | 
                |         iRequestType
                |             Type Of Request
                | 
                |                 DPMSingleSOIGeneration
                |                 DPMMultiSOIGeneration
                |                 DPMMultiSOIGenerationAtCS

        :param str i_requset_type:
        :rtype: None
        """
        return self.order_generator.set_RequestType(i_requset_type)

    def set_requested_node_details(self, i_proj_id: str, i_requested_node_id: str, i_effectivity: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_RequestedNodeDetails(CATBSTR iProjID,
                | CATBSTR iRequestedNodeID,
                | CATBSTR iEffectivity)
                | 
                |     Set Requested Node Details.
                | 
                |     Parameters:
                | 
                |         iProjID
                |             Object ID of the PPR Based Project 
                |         iRequestedNodeID
                |             Object ID of the node selected from PPR Based Project
                |             
                |         iEffectivity
                | 
                |             THIS PARAMETER HAS BEEN DEPRICATED FROM R17SP1 USE
                |             
                | 
                |         OrderGenerator.set_FilterInputString method to set your filters

        :param str i_proj_id:
        :param str i_requested_node_id:
        :param str i_effectivity:
        :rtype: None
        """
        return self.order_generator.set_RequestedNodeDetails(i_proj_id, i_requested_node_id, i_effectivity)

    def set_set_encryption_mode(self, i_encryptmode: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_SetEncryptionMode(boolean iEncryptmode)
                | 
                |     Set Encryption Mode.
                | 
                |     Parameters:
                | 
                |         iEncryptmode
                |             Encryption to be done?(True/False) for encrypting the SOR Package
                |             data

        :param bool i_encryptmode:
        :rtype: None
        """
        return self.order_generator.set_SetEncryptionMode(i_encryptmode)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_set_encryption_mode'
        # # vba_code = """
        # # Public Function set_set_encryption_mode(order_generator)
        # #     Dim iEncryptmode (2)
        # #     order_generator.set_SetEncryptionMode iEncryptmode
        # #     set_set_encryption_mode = iEncryptmode
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_transaction_id(self, i_transaction_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_TransactionID(CATBSTR iTransactionID)
                | 
                |     Set Transaction Type.
                | 
                |     Parameters:
                | 
                |         iTransactionID
                |             Transaction ID

        :param str i_transaction_id:
        :rtype: None
        """
        return self.order_generator.set_TransactionID(i_transaction_id)

    def set_update_release_table(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_UpdatereleaseTable(boolean iRequired)
                | 
                |     Set Update Release Table Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_UpdatereleaseTable(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_updaterelease_table'
        # # vba_code = """
        # # Public Function set_updaterelease_table(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_UpdatereleaseTable iRequired
        # #     set_updaterelease_table = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_zip(self, i_required: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_Zip(boolean iRequired)
                | 
                |     Set Zip Flag.
                | 
                |     Parameters:
                | 
                |         iRequired
                | 
                |             Legal values: TRUE/FALSE

        :param bool i_required:
        :rtype: None
        """
        return self.order_generator.set_Zip(i_required)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_zip'
        # # vba_code = """
        # # Public Function set_zip(order_generator)
        # #     Dim iRequired (2)
        # #     order_generator.set_Zip iRequired
        # #     set_zip = iRequired
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'OrderGenerator(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class CalibOffsets(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CalibOffsets
                | 
                | Interface to set Robot base/Tool offsets based on Calibration.
                | 
                | Role: This interface provides methods to get/set calibration offsets related to
                | Robot base and Robot tool position.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.calib_offsets = com_object

    def apply_corrected_base_offset(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyCorrectedBaseOffset()
                | 
                |     Applies corrected base offset.
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: None
        """
        return self.calib_offsets.ApplyCorrectedBaseOffset()

    def apply_corrected_tool_offset(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyCorrectedToolOffset()
                | 
                |     Applies corrected tool offset.
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: None
        """
        return self.calib_offsets.ApplyCorrectedToolOffset()

    def apply_nominal_base_offset(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyNominalBaseOffset()
                | 
                |     Applies the nominal base offset.
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: None
        """
        return self.calib_offsets.ApplyNominalBaseOffset()

    def apply_nominal_tool_offset(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyNominalToolOffset()
                | 
                |     Applies nominal tool offset.
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :rtype: None
        """
        return self.calib_offsets.ApplyNominalToolOffset()

    def get_calib_reference_file(self, o_calib_reference_file: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCalibReferenceFile(CATBSTR oCalibReferenceFile)
                | 
                |     Retrieve the reference calibration file.
                | 
                |     Parameters:
                | 
                |         iCalibReferenceFile
                |             Full path of reference calibration file. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str o_calib_reference_file:
        :rtype: None
        """
        return self.calib_offsets.GetCalibReferenceFile(o_calib_reference_file)

    def get_corrected_base_offset(
            self,
            x: float,
            y: float,
            z: float,
            roll: float,
            pitch: float,
            yaw: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCorrectedBaseOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Retrieve corrected base offset for the robot base wrt robot base reference
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Corrected robot base offset(in m).
                |             
                |         y
                |             Y coordinate of the Corrected robot base offset(in m).
                |             
                |         z
                |             Z coordinate of the Corrected robot base offset(in m).
                |             
                |         roll
                |             Roll angle of the Corrected robot base offset(in deg).
                |             
                |         pitch
                |             Pitch angle of the Corrected robot base offset(in deg).
                |             
                |         yaw
                |             Pitch angle of the Corrected robot base offset(in deg).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.GetCorrectedBaseOffset(x, y, z, roll, pitch, yaw)

    def get_corrected_tool_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCorrectedToolOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Retrieve corrected tool offset for the robot wrt robot mount
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Corrected tool offset(in m). 
                |         y
                |             Y coordinate of the Corrected tool offset(in m). 
                |         z
                |             Z coordinate of the Corrected tool offset(in m). 
                |         roll
                |             Roll angle of the Corrected tool offset(in deg). 
                |         pitch
                |             Pitch angle of the Corrected tool offset(in deg). 
                |         yaw
                |             Pitch angle of the Corrected tool offset(in deg). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.GetCorrectedToolOffset(x, y, z, roll, pitch, yaw)

    def get_nominal_base_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNominalBaseOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Retrieve nominal base offset for the robot base wrt robot base reference
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Nominal robot base offset(in m).
                |             
                |         y
                |             Y coordinate of the Nominal robot base offset(in m).
                |             
                |         z
                |             Z coordinate of the Nominal robot base offset(in m).
                |             
                |         roll
                |             Roll angle of the Nominal robot base offset(in deg).
                |             
                |         pitch
                |             Pitch angle of the Nominal robot base offset(in deg).
                |             
                |         yaw
                |             Pitch angle of the Nominal robot base offset(in deg).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.GetNominalBaseOffset(x, y, z, roll, pitch, yaw)

    def get_nominal_tool_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNominalToolOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Retrieve nominal tool offset for the robot wrt robot mount
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Nominal tool offset(in m). 
                |         y
                |             Y coordinate of the Nominal tool offset(in m). 
                |         z
                |             Z coordinate of the Nominal tool offset(in m). 
                |         roll
                |             Roll angle of the Nominal tool offset(in deg). 
                |         pitch
                |             Pitch angle of the Nominal tool offset(in deg). 
                |         yaw
                |             Pitch angle of the Nominal tool offset(in deg). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.GetNominalToolOffset(x, y, z, roll, pitch, yaw)

    def get_reference_base_position(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetReferenceBasePosition(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Retrieve current reference base position of robot.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the reference base position(in m).
                |             
                |         y
                |             Y coordinate of the reference base position(in m).
                |             
                |         z
                |             Z coordinate of the reference base position(in m).
                |             
                |         roll
                |             Roll angle of the reference base position(in deg).
                |             
                |         pitch
                |             Pitch angle of the reference base position(in deg).
                |             
                |         yaw
                |             Yaw angle of the reference base position(in deg). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.GetReferenceBasePosition(x, y, z, roll, pitch, yaw)

    def set_calib_reference_file(self, i_calib_reference_file: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCalibReferenceFile(CATBSTR iCalibReferenceFile)
                | 
                |     Set the reference calibration file.
                | 
                |     Parameters:
                | 
                |         iCalibReferenceFile
                |             Full path of reference calibration file. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str i_calib_reference_file:
        :rtype: None
        """
        return self.calib_offsets.SetCalibReferenceFile(i_calib_reference_file)

    def set_corrected_base_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCorrectedBaseOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Set corrected base offset for the robot base wrt robot base reference
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Corrected robot base offset(in m).
                |             
                |         y
                |             Y coordinate of the Corrected robot base offset(in m).
                |             
                |         z
                |             Z coordinate of the Corrected robot base offset(in m).
                |             
                |         roll
                |             Roll angle of the Corrected robot base offset(in deg).
                |             
                |         pitch
                |             Pitch angle of the Corrected robot base offset(in deg).
                |             
                |         yaw
                |             Pitch angle of the Corrected robot base offset(in deg).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.SetCorrectedBaseOffset(x, y, z, roll, pitch, yaw)

    def set_corrected_tool_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCorrectedToolOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Set corrected tool offset for the robot wrt robot mount
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Corrected tool offset(in m). 
                |         y
                |             Y coordinate of the Corrected tool offset(in m). 
                |         z
                |             Z coordinate of the Corrected tool offset(in m). 
                |         roll
                |             Roll angle of the Corrected tool offset(in deg). 
                |         pitch
                |             Pitch angle of the Corrected tool offset(in deg). 
                |         yaw
                |             Pitch angle of the Corrected tool offset(in deg). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.SetCorrectedToolOffset(x, y, z, roll, pitch, yaw)

    def set_nominal_base_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNominalBaseOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Set nominal base offset for the robot base wrt robot base reference
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Nominal robot base offset(in m).
                |             
                |         y
                |             Y coordinate of the Nominal robot base offset(in m).
                |             
                |         z
                |             Z coordinate of the Nominal robot base offset(in m).
                |             
                |         roll
                |             Roll angle of the Nominal robot base offset(in deg).
                |             
                |         pitch
                |             Pitch angle of the Nominal robot base offset(in deg).
                |             
                |         yaw
                |             Pitch angle of the Nominal robot base offset(in deg).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.SetNominalBaseOffset(x, y, z, roll, pitch, yaw)

    def set_nominal_tool_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNominalToolOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Set nominal tool offset for the robot wrt robot mount
                |     position.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Nominal tool offset(in m). 
                |         y
                |             Y coordinate of the Nominal tool offset(in m). 
                |         z
                |             Z coordinate of the Nominal tool offset(in m). 
                |         roll
                |             Roll angle of the Nominal tool offset(in deg). 
                |         pitch
                |             Pitch angle of the Nominal tool offset(in deg). 
                |         yaw
                |             Pitch angle of the Nominal tool offset(in deg). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.SetNominalToolOffset(x, y, z, roll, pitch, yaw)

    def set_reference_base_position(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetReferenceBasePosition(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Set reference base position of robot.
                | 
                |     Parameters:
                | 
                |         x
                |             X coordinate of the Robot base position(in m). 
                |         y
                |             Y coordinate of the Robot base position(in m). 
                |         z
                |             Z coordinate of the Robot base position(in m). 
                |         roll
                |             Roll angle of the Robot Base position(in deg). 
                |         pitch
                |             Pitch angle of the Robot Base position(in deg). 
                |         yaw
                |             Pitch angle of the Robot Base position(in deg). 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.calib_offsets.SetReferenceBasePosition(x, y, z, roll, pitch, yaw)

    def __repr__(self):
        return f'CalibOffsets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchSession(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchSession
                | 
                | Represents a schematic session.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_session = com_object

    def create_document(self, i_doc_type: str, i_b_interactive: bool, o_new_doc: Document) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateDocument(CATBSTR iDocType,
                | boolean iBInteractive,
                | Document oNewDoc)
                | 
                |     Create a document with Schematic context.
                | 
                |     Parameters:
                | 
                |         iDocType
                |             Document type, if NULL "Product" is assumed. These are the types
                |             shown in the File+New list 
                |         iBInteractive
                |             If TRUE, document is created in interactive session with editor
                |             
                |         oNewDoc
                |             Document created. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchSession
                |          Dim strVar1 As String
                |          Dim bVar2 As boolean
                |          Dim objArg3 As Document
                |           ...
                |          objThisIntf.CreateDocumentstrVar1,bVar2,objArg3

        :param str i_doc_type:
        :param bool i_b_interactive:
        :param Document o_new_doc:
        :rtype: None
        """
        return self.sch_session.CreateDocument(i_doc_type, i_b_interactive, o_new_doc.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_document'
        # # vba_code = """
        # # Public Function create_document(sch_session)
        # #     Dim iDocType (2)
        # #     sch_session.CreateDocument iDocType
        # #     create_document = iDocType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_current_application_id(self, o_application_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCurrentApplicationID(CATBSTR oApplicationID)
                | 
                |     Get the current application ID.
                | 
                |     Parameters:
                | 
                |         oApplicationID
                |             Application ID 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchSession
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.GetCurrentApplicationIDstrVar1

        :param str o_application_id:
        :rtype: None
        """
        return self.sch_session.GetCurrentApplicationID(o_application_id)

    def get_current_document(self) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCurrentDocument() As Document
                | 
                |     Get the current document.
                | 
                |     Parameters:
                | 
                |         oCurDoc
                |             Pointer to current document. DO NOT NEED TO RELEASE OUTPUT POINTER.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchSession
                |          Dim objArg1 As Document
                |           ...
                |          Set objArg1 = objThisIntf.GetCurrentDocument

        :rtype: Document
        """
        return Document(self.sch_session.GetCurrentDocument())

    def get_sch_ext_container(self, i_doc: Document) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSchExtContainer(Document iDoc) As AnyObject
                | 
                |     Get the schematic container (e.g. for CATISchBaseFactory
                |     implementation).
                | 
                |     Parameters:
                | 
                |         iDoc
                |             Document in the session to retreive the container from
                |             
                |         oContainer
                |             Schematic container shown in the File+New list 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchSession
                |          Dim objArg1 As Document
                |          Dim objArg2 As AnyObject
                |           ...
                |          Set objArg2 = objThisIntf.GetSchExtContainer(objArg1)

        :param Document i_doc:
        :rtype: AnyObject
        """
        return AnyObject(self.sch_session.GetSchExtContainer(i_doc.com_object))

    def set_current_application_id(self, i_application_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentApplicationID(CATBSTR iApplicationID)
                | 
                |     Set the current application ID.
                | 
                |     Parameters:
                | 
                |         iApplicationID
                |             Application ID 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchSession
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.SetCurrentApplicationIDstrVar1

        :param str i_application_id:
        :rtype: None
        """
        return self.sch_session.SetCurrentApplicationID(i_application_id)

    def set_current_document(self, i_cur_doc: Document) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentDocument(Document iCurDoc)
                | 
                |     Set the current document.
                | 
                |     Parameters:
                | 
                |         iCurDoc
                |             Pointer to current document. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchSession
                |          Dim objArg1 As Document
                |           ...
                |          objThisIntf.SetCurrentDocumentobjArg1

        :param Document i_cur_doc:
        :rtype: None
        """
        return self.sch_session.SetCurrentDocument(i_cur_doc.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_current_document'
        # # vba_code = """
        # # Public Function set_current_document(sch_session)
        # #     Dim iCurDoc (2)
        # #     sch_session.SetCurrentDocument iCurDoc
        # #     set_current_document = iCurDoc
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchSession(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_smooth_step_amplitude import ABQSmoothStepAmplitude
from pycatia.abq_automation_interfaces.abq_tabular_amplitude import ABQTabularAmplitude
from pycatia.analysis_interfaces.analysis_supports import AnalysisSupports
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject


class ABQLoad(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQLoad
                | 
                | Represents the base interface for all load objects.
                | Role: The ABQLoad interface manages the common properties of any
                | load.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_load = com_object

    @property
    def activation_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActivationStatus() As boolean
                | 
                |     Sets or returns the activation status.
                | 
                |     Returns:
                |         A boolean specifying whether the pressure is activated.

        :rtype: bool
        """

        return self.abq_load.ActivationStatus

    @activation_status.setter
    def activation_status(self, value: bool):
        """
        :param bool value:
        """

        self.abq_load.ActivationStatus = value

    @property
    def amplitude(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Amplitude() As CATBSTR
                | 
                |     Sets or returns the amplitude, given the name of the
                |     amplitude.
                | 
                |     Returns:
                |         The amplitude object selected.

        :rtype: str
        """

        return self.abq_load.Amplitude

    @amplitude.setter
    def amplitude(self, value: str):
        """
        :param str value:
        """

        self.abq_load.Amplitude = value

    @property
    def regions(self) -> AnalysisSupports:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Regions() As AnalysisSupports (Read Only)
                | 
                |     Returns the region to which the load is applied.
                | 
                |     Returns:
                |         The region.

        :rtype: AnalysisSupports
        """

        return AnalysisSupports(self.abq_load.Regions)

    @property
    def smooth_amplitude(self) -> ABQSmoothStepAmplitude:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SmoothAmplitude() As ABQSmoothStepAmplitude
                | 
                |     Sets or returns the Smooth Amplitude, given the refernce of the Smooth
                |     amplitude.
                | 
                |     Returns:
                |         The amplitude object selected.

        :rtype: ABQSmoothStepAmplitude
        """

        return ABQSmoothStepAmplitude(self.abq_load.SmoothAmplitude)

    @smooth_amplitude.setter
    def smooth_amplitude(self, value: ABQSmoothStepAmplitude):
        """
        :param ABQSmoothStepAmplitude value:
        """

        self.abq_load.SmoothAmplitude = value

    @property
    def status(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Status() As CATBSTR (Read Only)
                | 
                |     Returns the propagating status of the load.
                | 
                |     Returns:
                |         The propagating status for example: if the load feature is created, it
                |         will return "CREATED" if the load feature is propagated from previous step, it
                |         will return "PROPAGATED"

        :rtype: str
        """

        return self.abq_load.Status

    @property
    def tabular_amplitude(self) -> ABQTabularAmplitude:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TabularAmplitude() As ABQTabularAmplitude
                | 
                |     Sets or returns the amplitude, given the Tabular amplitude
                |     refrence.
                | 
                |     Returns:
                |         The amplitude object selected.

        :rtype: ABQTabularAmplitude
        """

        return ABQTabularAmplitude(self.abq_load.TabularAmplitude)

    @tabular_amplitude.setter
    def tabular_amplitude(self, value: ABQTabularAmplitude):
        """
        :param ABQTabularAmplitude value:
        """

        self.abq_load.TabularAmplitude = value

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the load.
                | 
                |     Returns:
                |         The type of the load.

        :rtype: str
        """

        return self.abq_load.Type

    @property
    def use_amplitude(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseAmplitude() As boolean
                | 
                |     Sets or returns a boolean indicating whether amplitude is used in a
                |     load
                | 
                |     Returns:
                |         boolean specifying whether user defined amplitude is active.

        :rtype: bool
        """

        return self.abq_load.UseAmplitude

    @use_amplitude.setter
    def use_amplitude(self, value: bool):
        """
        :param bool value:
        """

        self.abq_load.UseAmplitude = value

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the load is
                |             applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the load is
                |             applied.
                | 
                |             Refer: CATIAReference , CATIAProduct

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_load.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(abq_load)
        # #     Dim iProduct (2)
        # #     abq_load.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the load is
                |             applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the load is
                |             applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_load.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_load)
        # #     Dim iProduct (2)
        # #     abq_load.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The CATIA Reference specifying the object to which the load is
                |             applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the load is
                |             applied.
                | 
                |             Refer: CATIAReference

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_load.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_load)
        # #     Dim iReference (2)
        # #     abq_load.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQLoad(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.point import Point
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapePointCoord(Point):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Point
                |                             HybridShapePointCoord
                | 
                | Point defined by coordinates.
                | Role: To access data of the point feature created with its cartesian
                | coordinates.
                | 
                | See also:
                |     Length 
                | See also:
                |     Reference 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_point_coord = com_object

    @property
    def pt_ref(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PtRef() As Reference
                | 
                |     Returns or Sets the reference point for PointCoord
                |     feature.
                |     This data is not mandatory, if element is null, the origin point is
                |     taken.
                |     When an element is given, X, Y and Z are measured starting from this
                |     point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example
                |     :
                |         This example retrieves in oPtRef the reference point for PointCoord
                |         feature.
                | 
                |          Dim oPtRef As CATIAReference
                |          Set oPtRef  = PointCoord.PtRef

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_coord.PtRef)

    @pt_ref.setter
    def pt_ref(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_point_coord.PtRef = reference_point.com_object

    @property
    def ref_axis_system(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RefAxisSystem() As Reference
                | 
                |     Returns or Sets the reference Axis System for PointCoord
                |     feature.
                |     This data is not mandatory, if element is null, the absolute axis system is
                |     taken.
                |     When an element is given, X, Y and Z are considered in this Axis
                |     system.
                |     If reference point is not specified, X,Y and Z are measured from origin of
                |     this axis system. *
                | 
                |     Example
                |     :
                |         This example retrieves in oRefAxis the reference Axis System for
                |         PointCoord feature.
                | 
                |          Dim oRefAxis As CATIAReference
                |          Set oRefAxis  = PointCoord.RefAxisSystem

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_coord.RefAxisSystem)

    @ref_axis_system.setter
    def ref_axis_system(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_point_coord.RefAxisSystem = reference_axis.com_object

    @property
    def x(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property X() As Length (Read Only)
                | 
                |     Returns X coordinate of the point.
                | 
                |     Example
                |     :
                |         This example retrieves in oX the X coordinate for the PointCoord hybrid
                |         shape feature.
                | 
                |          Dim oX As CATIALength
                |          Set oX = PointCoord.X

        :rtype: Length
        """

        return Length(self.hybrid_shape_point_coord.X)

    @property
    def y(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Y() As Length (Read Only)
                | 
                |     Returns Y coordinate of the point.
                | 
                |     Example
                |     :
                |         This example retrieves in oY the Y coordinate for the PointCoord hybrid
                |         shape feature.
                | 
                |          Dim oY As CATIALength
                |          Set oY = PointCoord.Y

        :rtype: Length
        """

        return Length(self.hybrid_shape_point_coord.Y)

    @property
    def z(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Z() As Length (Read Only)
                | 
                |     Returns Z coordinate of the point.
                | 
                |     Example
                |     :
                |         This example retrieves in oZ the Z coordinate for the PointCoord hybrid
                |         shape feature.
                | 
                |          Dim oZ As CATIALength
                |          Set oZ = PointCoord.Z

        :rtype: Length
        """

        return Length(self.hybrid_shape_point_coord.Z)

    def __repr__(self):
        return f'HybridShapePointCoord(name="{self.name}")'
